@@ -2,7 +2,7 @@
 """Gaussian input plugin."""
 from __future__ import absolute_import
 
-from aiida.orm import Dict, List, RemoteData, Float
+from aiida.orm import Dict, RemoteData, Float
 from aiida.common import CalcInfo, CodeInfo
 
 # from aiida.cmdline.utils import echo
@@ -42,7 +42,8 @@ class GaussianCalculation(CalcJob):
     # Defaults
     INPUT_FILE = "aiida.inp"
     OUTPUT_FILE = "aiida.out"
-    DEFAULT_PARSER = "gaussian_base_parser"
+    PARENT_FOLDER_NAME = "parent_calc"
+    DEFAULT_PARSER = "gaussian.base"
 
     @classmethod
     def define(cls, spec):
@@ -56,10 +57,7 @@ class GaussianCalculation(CalcJob):
             help="Input structure; will be converted to pymatgen object",
         )
 
-        spec.input("parameters",
-                   valid_type=Dict,
-                   required=True,
-                   help="Input parameters")
+        spec.input("parameters", valid_type=Dict, required=True, help="Input parameters")
         spec.input(
             "settings",
             valid_type=Dict,
@@ -118,6 +116,11 @@ class GaussianCalculation(CalcJob):
             "ERROR_OUTPUT_MISSING",
             message="The retrieved folder did not contain the output file.",
         )
+        spec.exit_code(
+            211,
+            "ERROR_OUTPUT_LOG_READ",
+            message="The retrieved output log could not be read.",
+        )
         spec.exit_code(
             220,
             "ERROR_OUTPUT_PARSING",
@@ -126,8 +129,7 @@ class GaussianCalculation(CalcJob):
         spec.exit_code(
             301,
             "ERROR_SCF_FAILURE",
-            message=
-            "The SCF did not converge and the calculation was terminated.",
+            message="The SCF did not converge and the calculation was terminated.",
         )
         spec.exit_code(
             390,
@@ -137,8 +139,7 @@ class GaussianCalculation(CalcJob):
         spec.exit_code(
             391,
             "ERROR_NO_NORMAL_TERMINATION",
-            message=
-            "The log did not contain 'Normal termination' (probably out of time).",
+            message="The log did not contain 'Normal termination' (probably out of time).",
         )
 
     # --------------------------------------------------------------------------
@@ -159,13 +160,13 @@ class GaussianCalculation(CalcJob):
 
         # Generate the input file
         input_string = GaussianCalculation._render_input_string_from_params(
-            self.inputs.parameters.get_dict(), pmg_structure)
+            self.inputs.parameters.get_dict(), pmg_structure
+        )
 
         with open(folder.get_abs_path(self.INPUT_FILE), "w") as out_file:
             out_file.write(input_string)
 
-        settings = self.inputs.settings.get_dict(
-        ) if "settings" in self.inputs else {}
+        settings = self.inputs.settings.get_dict() if "settings" in self.inputs else {}
 
         # create code info
         codeinfo = CodeInfo()
@@ -192,9 +193,9 @@ class GaussianCalculation(CalcJob):
         if "parent_calc_folder" in self.inputs:
             comp_uuid = self.inputs.parent_calc_folder.computer.uuid
             remote_path = self.inputs.parent_calc_folder.get_remote_path()
-            copy_info = (comp_uuid, remote_path, "parent_calc")
-            if (self.inputs.code.computer.uuid == comp_uuid
-                ):  # if running on the same computer - make a symlink
+            copy_info = (comp_uuid, remote_path, self.PARENT_FOLDER_NAME)
+            if (self.inputs.code.computer.uuid == comp_uuid):
+                # if running on the same computer - make a symlink
                 # if not - copy the folder
                 calcinfo.remote_symlink_list.append(copy_info)
             else:
@@ -218,15 +219,13 @@ class GaussianCalculation(CalcJob):
             pmg_structure,
             title="input generated by the aiida-gaussian plugin",
             charge=param_dict.get("charge"),
-            spin_multiplicity=param_dict.get(
-                "multiplicity", param_dict.get("spin_multiplicity")),
+            spin_multiplicity=param_dict.get("multiplicity", param_dict.get("spin_multiplicity")),
             functional=param_dict.get("functional"),
             basis_set=param_dict.get("basis_set"),
             route_parameters=param_dict.get("route_parameters"),
             input_parameters=param_dict.get("input_parameters"),
             link0_parameters=param_dict.get("link0_parameters"),
-            dieze_tag=param_dict.get("dieze_tag",
-                                     "#N"),  # normal print level by default
+            dieze_tag=param_dict.get("dieze_tag", "#N"),  # normal print level by default
         )
 
         return inp.to_string(cart_coords=True)
